@@ -34,6 +34,7 @@ from string import *
 #-------------------------------------------------------------------------------
 
 import matplotlib
+matplotlib.use("Agg")
 
 #-------------------------------------------------------------------------------
 # matplotlib config
@@ -49,7 +50,7 @@ rcParams['ytick.labelsize'] = 'large'
 rcParams['figure.dpi']      = 200
 rcParams['figure.figsize']  = (4,4)
 rcParams['font.family']     = 'sans-serif'
-rcParams['text.usetex']     = True
+#rcParams['text.usetex']     = True
 
 #-------------------------------------------------------------------------------
 # additional colors
@@ -455,7 +456,7 @@ class Plotter(object):
                         curve = Probes(f, fig, ycol)
                         self.curves.append(curve)
 
-        # Read the files of results
+        # Read the files of results of cases
         for case in study_object.Cases:
             if case.plot == "on" and case.is_run != "KO":
                 for node in self.parser.getChilds(case.node, "data"):
@@ -478,6 +479,7 @@ class Plotter(object):
                                          study_label,
                                          case.label, "RESU",
                                          d, "monitoring", file_name)
+
                         if not os.path.isfile(f):
                             raise ValueError, "\n\nThis file does not exist: %s\n\n" % f
 
@@ -486,6 +488,24 @@ class Plotter(object):
                         curve.setMeasurement(False)
                         self.curves.append(curve)
 
+        # Read the files of results of postpro
+        script, label, nodes, args = self.parser.getPostPro(study_label)
+        for i in range(len(label)):
+            if script[i]:
+                for node in self.parser.getChilds(nodes[i], "data"):
+                    plots, file_name, dest, repo = self.parser.getResult(node)
+
+                    dd = self.parser.getDestination()
+                    f = os.path.join(dd, study_label, "POST", file_name)
+
+                    if not os.path.isfile(f):
+                        raise ValueError, "\n\nThis file does not exist: %s\n\n" % f
+
+                    for nn in plots:
+                        curve = Plot(nn, self.parser, f)
+                        curve.setMeasurement(False)
+                        self.curves.append(curve)
+
         subplots = []
         for node in self.parser.getSubplots(study_label):
             subplots.append(Subplot(node, self.parser, self.curves))
@@ -552,7 +572,7 @@ class Plotter(object):
             try:
                 execfile("./tmp.py")
             except:
-                print "Error with the matplotlib command: %s" % cmd
+                print("Error with the matplotlib command: %s" % cmd)
             os.remove("./tmp.py")
 
         plt.hold(True)
@@ -629,7 +649,7 @@ class Plotter(object):
             try:
                 execfile("./tmp.py")
             except:
-                print "Error with the matplotlib command: %s" % cmd
+                print("Error with the matplotlib command: %s" % cmd)
             os.remove("./tmp.py")
 
         # Layout
@@ -678,7 +698,7 @@ class Plotter(object):
                 try:
                     execfile("./tmp.py")
                 except:
-                    print "Error with the matplotlib command: %s" % cmd
+                    print("Error with the matplotlib command: %s" % cmd)
                 os.remove("./tmp.py")
 
 
