@@ -62,13 +62,14 @@ def nodot(item):
 #-------------------------------------------------------------------------------
 
 class Case(object):
-    def __init__(self, pkg, rlog, diff, study, data, repo, dest):
+    def __init__(self, pkg, rlog, diff, parser, study, data, repo, dest):
         """
         @type data: C{Dictionary}
         @param data: contains all keyword and value read in the parameters file
         """
         self.__log      = rlog
         self.__diff     = diff
+        self.__parser   = parser
         self.__study    = study
         self.__data     = data
         self.__repo     = repo
@@ -79,6 +80,7 @@ class Case(object):
         self.compute    = data['compute']
         self.plot       = data['post']
         self.run_id     = data['run_id']
+        self.compare    = data['compare']
 
         self.is_compil  = "not done"
         self.is_run     = "not done"
@@ -349,20 +351,18 @@ class Case(object):
         return error
 
 
-    def compare(self, r, d, threshold, args):
+    def runCompare(self, studies, r, d, threshold, args):
         home = os.getcwd()
 
-        repo = os.path.join(self.__repo, self.label,
-                            'RESU', r, 'checkpoint', 'main')
-        if not os.path.isfile(repo):
-            msg = "In %s \nthe directory %s does not exist.\n" % (repo, r)
-            raise ValueError, msg
+        node = None
 
-        dest = os.path.join(self.__dest, self.label,
-                            'RESU', d, 'checkpoint', 'main')
-        if not os.path.isfile(dest):
-            msg = "In %s \nthe directory %s does not exist.\n" % (dest, d)
-            raise ValueError, msg
+        result = os.path.join(self.__repo, self.label, 'RESU')
+        repo = self.check_dir(studies, node, result, r, "repo")
+        repo = os.path.join(result, repo, 'checkpoint', 'main')
+
+        result = os.path.join(self.__dest, self.label, 'RESU')
+        dest = self.check_dir(studies, node, result, d, "dest")
+        dest = os.path.join(result, dest, 'checkpoint', 'main')
 
         cmd = self.__diff + ' ' + repo + ' ' + dest
 
@@ -374,9 +374,11 @@ class Case(object):
         if args != None:
             cmd += (" " + args)
             l = string.split(args)
-            i = l.find('--threshold')
-            if i > -1:
+            try:
+                i = l.index('--threshold')
                 self.threshold = l[i+1]
+            except:
+                pass
 
         l = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).stdout
         info = l.read().replace("\"", " ").replace(";", " ").replace(":", " ").split()
@@ -395,6 +397,91 @@ class Case(object):
 
         return tab
 
+
+    def check_dir(self, studies, node, result, rep, attr):
+        """
+        Check coherency between xml file of parameters and repository or destination.
+        """
+        # 1. Check if the given result directory exists.
+        if rep != "":
+            rep_f = os.path.join(result, rep)
+            rep_e = os.path.join(result, rep, 'error')
+
+            if not os.path.isdir(rep_f):
+                msg = "Study %s case %s:\nthe directory %s does not exist.\nStop.\n" % \
+                    (self.__study, self.label, rep_f)
+                studies.reporting(msg)
+                sys.exit(1)
+
+            if os.path.isfile(rep_e):
+                msg = "Study %s case %s:\nthe directory %s contains an error file.\nStop.\n" % \
+                    (self.__study, self.label, rep_f)
+                studies.reporting(msg)
+                sys.exit(1)
+
+            return rep
+
+        # 2. The result directory must be read automatically;
+        #    check if there is a single result directory.
+        elif rep == "":
+            if len(filter(nodot, os.listdir(result))) == 0:
+                msg = "Study %s case %s:\nthere is no result directory in %s\nStop.\n" % \
+                    (self.__study, self.label, result)
+                studies.reporting(msg)
+                sys.exit(1)
+
+            # if no run_id is specified in the xml file
+            # only one result directory allowed in RESU
+            if len(filter(nodot, os.listdir(result))) > 1 and self.run_id == "":
+                msg = "Study %s case %s:\nthere are several directories in %s\nStop.\n" % \
+                    (self.__study, self.label, result)
+                studies.reporting(msg)
+                sys.exit(1)
+
+            rep = self.run_id
+            # if no run_id is specified in the xml file
+            # the only result directory present in RESU is taken
+            if rep == "":
+                rep = filter(nodot, os.listdir(result))[0]
+
+            rep_f = os.path.join(result, rep)
+            if not os.path.isdir(rep_f):
+                msg = "Study %s case %s:\nthe directory %s does not exist.\nStop.\n" % \
+                    (self.__study, self.label, rep_f)
+                studies.reporting(msg)
+                sys.exit(1)
+
+            rep_e = os.path.join(result, rep, 'error')
+            if os.path.isfile(rep_e):
+                msg = "Study %s case %s:\nthe directory %s contains an error file.\nStop.\n" % \
+                    (self.__study, self.label, rep_f)
+                studies.reporting(msg)
+                sys.exit(1)
+
+            # 3. Update the file of parameters with the name of the result directory
+            if node:
+                self.__parser.setAttribute(node, attr, rep)
+            return rep
+
+        else:
+            studies.reporting('Error: check compare/script/plot/probe/resu/input failed.')
+            sys.exit(1)
+
+
+    def check_dirs(self, studies, node, repo, dest):
+        """
+        Check coherency between xml file of parameters and repository and destination.
+        """
+        if repo != None:
+            # build path to RESU directory with path to study and case label in the repo
+            result = os.path.join(self.__repo, self.label, 'RESU')
+            self.check_dir(studies, node, result, repo, "repo")
+
+        if dest != None:
+            # build path to RESU directory with path to study and case label in the dest
+            result = os.path.join(self.__dest, self.label, 'RESU')
+            self.check_dir(studies, node, result, dest, "dest")
+
 #-------------------------------------------------------------------------------
 
 class Study(object):
@@ -443,6 +530,7 @@ class Study(object):
                 c = Case(pkg,
                          self.__log,
                          self.__diff,
+                         self.__parser,
                          self.__study,
                          data,
                          self.__repo,
@@ -742,6 +830,9 @@ class Studies(object):
                     os.chdir(os.path.join(self.dest, l, "MESH"))
                     # prepro external script might need the pythondir
                     pdir = case.pkg.get_dir('pkgpythondir')
+                    if case.pkg.code_name == "NEPTUNE_CFD":
+                        sdir = case.pkg.get_cs_dir('pkgpythondir')
+                        pdir = pdir + ":" + sdir
                     retcode, t = run_autovnv_command(cmd, self.__log, pythondir = pdir)
                     os.chdir(repbase)
                     self.reporting('    - script %s --> OK (%s s)' % (cmd, t))
@@ -786,122 +877,64 @@ class Studies(object):
                         self.__log.flush()
 
 
-    def __check_dir(self, study_label, case_label, run_id, node, result, rep, attr):
-        """
-        Check coherency between xml file of parameters and repository or destination.
-        """
-        # 1. Check if the given result directory exists.
-        if rep != "":
-            rep_f = os.path.join(result, rep)
-            rep_e = os.path.join(result, rep, 'error')
-
-            if not os.path.isdir(rep_f):
-                msg = "Study %s case %s:\nthe directory %s does not exist.\nStop.\n" % \
-                    (study_label, case_label, rep_f)
-                self.reporting(msg)
-                sys.exit(1)
-
-            if os.path.isfile(rep_e):
-                msg = "Study %s case %s:\nthe directory %s contains an error file.\nStop.\n" % \
-                    (study_label, case_label, rep_f)
-                self.reporting(msg)
-                sys.exit(1)
-
-        # 2. The result directory must be read automatically;
-        #    check if there is a single result directory.
-        elif rep == "":
-            if len(filter(nodot, os.listdir(result))) == 0:
-                msg = "Study %s case %s:\nthere is no result directory in %s\nStop.\n" % \
-                    (study_label, case_label, result)
-                self.reporting(msg)
-                sys.exit(1)
-
-            # if no run_id is specified in the xml file
-            # only one result directory allowed in RESU
-            if len(filter(nodot, os.listdir(result))) > 1 and run_id == "":
-                msg = "Study %s case %s:\nthere are several directories in %s\nStop.\n" % \
-                    (study_label, case_label, result)
-                self.reporting(msg)
-                sys.exit(1)
-
-            rep = run_id
-            # if no run_id is specified in the xml file
-            # the only result directory present in RESU is taken
-            if rep == "":
-                rep = filter(nodot, os.listdir(result))[0]
-
-            rep_f = os.path.join(result, rep)
-            if not os.path.isdir(rep_f):
-                msg = "Study %s case %s:\nthe directory %s does not exist.\nStop.\n" % \
-                    (study_label, case_label, rep_f)
-                self.reporting(msg)
-                sys.exit(1)
-
-            rep_e = os.path.join(result, rep, 'error')
-            if os.path.isfile(rep_e):
-                msg = "Study %s case %s:\nthe directory %s contains an error file.\nStop.\n" % \
-                    (study_label, case_label, rep_f)
-                self.reporting(msg)
-                sys.exit(1)
-
-        # 3. Update the file of parameters with the name of the result directory
-            if node:
-                self.__parser.setAttribute(node, attr, rep)
-            return rep
-
-        else:
-            self.reporting('Error: check compare/script/plot/probe/resu/input failed.')
-            sys.exit(1)
-
-
-    def __check_dirs(self, study_label, case_label, run_id, node, repo, dest):
-        """
-        Check coherency between xml file of parameters and repository and destination.
-        """
-        if repo != None:
-            result = os.path.join(self.repo, study_label, case_label, 'RESU')
-            self.__check_dir(study_label, case_label, run_id, node, result, repo, "repo")
-
-        if dest != None:
-            result = os.path.join(self.dest, study_label, case_label, 'RESU')
-            self.__check_dir(study_label, case_label, run_id, node, result, dest, "dest")
-
-
     def check_compare(self, destination=True):
         """
         Check coherency between xml file of parameters and repository.
-        Stop if you try to make a comparison with a file which does not exsist.
+        Stop if you try to make a comparison with a file which does not exist.
         """
         for l, s in self.studies:
             for case in s.Cases:
-                compare, nodes, repo, dest, threshold, args = self.__parser.getCompare(case.node)
-                for i in range(len(nodes)):
-                    if compare[i] and case.is_run != "KO":
+                if case.compare == 'on' and case.is_run != "KO":
+                    compare, nodes, repo, dest, threshold, args = self.__parser.getCompare(case.node)
+                    if compare:
+                        is_checked = False
+                        for i in range(len(nodes)):
+                            if compare[i]:
+                                is_checked = True
+                                if destination == False:
+                                    dest[i]= None
+                                case.check_dirs(self, nodes[i], repo[i], dest[i])
+                    if not compare or not is_checked:
+                        node = None
+                        repo = ""
+                        dest = ""
                         if destination == False:
-                            dest[i]= None
-                        self.__check_dirs(l, case.label, case.run_id, nodes[i], repo[i], dest[i])
+                            dest = None
+                        case.check_dirs(self, node, repo, dest)
 
 
     def compare(self):
         """
-        Compare the results of the new computations with thoses from the Repository.
+        Compare the results of the new computations with those from the Repository.
         """
         if self.__compare:
             for l, s in self.studies:
                 self.reporting('  o Compare study: ' + l)
                 for case in s.Cases:
-                    is_compare, nodes, repo, dest, t, args = self.__parser.getCompare(case.node)
-                    for i in range(len(nodes)):
-                        if is_compare[i] and case.is_run != "KO":
+                    if case.compare == 'on' and case.is_run != "KO":
+                        is_compare, nodes, repo, dest, t, args = self.__parser.getCompare(case.node)
+                        if is_compare:
+                            for i in range(len(nodes)):
+                                if is_compare[i]:
+                                    case.is_compare = "done"
+                                    self.reporting('    - compare %s (%s)' % (case.label, args[i]))
+                                    case.diff_value += case.runCompare(self, repo[i], dest[i], t[i], args[i])
+                        if not is_compare or case.is_compare != "done":
+                            repo = ""
+                            dest = ""
+                            t    = None
+                            args = None
                             case.is_compare = "done"
-                            self.reporting('    - compare %s (%s)' % (case.label, args[i]))
-                            case.diff_value += case.compare(repo[i], dest[i], t[i], args[i])
+                            self.reporting('    - compare %s (%s)' % (case.label, args))
+                            case.diff_value += case.runCompare(self, repo, dest, t, args)
+
+
 
 
     def check_script(self, destination=True):
         """
         Check coherency between xml file of parameters and repository.
-        Stop if you try to run a script with a file which does not exsist.
+        Stop if you try to run a script with a file which does not exist.
         """
         for l, s in self.studies:
             for case in s.Cases:
@@ -910,7 +943,7 @@ class Studies(object):
                     if script[i] and case.is_run != "KO":
                         if destination == False:
                             dest[i] = None
-                        self.__check_dirs(l, case.label, case.run_id, nodes[i], repo[i], dest[i])
+                        case.check_dirs(self, nodes[i], repo[i], dest[i])
 
 
     def scripts(self):
@@ -949,7 +982,7 @@ class Studies(object):
                 if case.is_run != "KO":
                     if case.run_dir == "":
                         resu = os.path.join(self.dest, l, case.label, 'RESU')
-                        rep = self.__check_dir(l, case.label, case.run_id, None, resu, "", "dest")
+                        rep = case.check_dir(self, None, resu, "", "dest")
                         case.run_id = rep
                         case.run_dir = os.path.join(resu, rep)
 
@@ -979,26 +1012,26 @@ class Studies(object):
                         plots, file, dest, repo = self.__parser.getResult(node)
                         if destination == False:
                             dest = None
-                        self.__check_dirs(l, case.label, case.run_id, node, repo, dest)
+                        case.check_dirs(self, node, repo, dest)
 
                     for node in self.__parser.getChilds(case.node, "probes"):
                         file, dest, fig = self.__parser.getProbes(node)
                         if destination == False:
                             dest = None
                         repo = None
-                        self.__check_dirs(l, case.label, case.run_id, node, repo, dest)
+                        case.check_dirs(self, node, repo, dest)
 
                     for node in self.__parser.getChilds(case.node, "resu"):
                         plots, file, dest, repo = self.__parser.getResult(node)
                         if destination == False:
                             dest = None
-                        self.__check_dirs(l, case.label, case.run_id, node, repo, dest)
+                        case.check_dirs(self, node, repo, dest)
 
                     for node in self.__parser.getChilds(case.node, "input"):
                         file, dest, repo = self.__parser.getInput(node)
                         if destination == False:
                             dest = None
-                        self.__check_dirs(l, case.label, case.run_id, node, repo, dest)
+                        case.check_dirs(self, node, repo, dest)
 
 
     def plot(self):
@@ -1064,7 +1097,10 @@ class Studies(object):
 
                 for case in s.Cases:
                     if case.is_compare == "done":
-                        doc2.appendLine("\\subsection{Comparison for case %s}" % case.label)
+                        run_id = None
+                        if case.run_id != "":
+                            run_id = case.run_id
+                        doc2.appendLine("\\subsection{Comparison for case %s (run_id: %s)}" % (case.label, run_id))
                         if case.diff_value:
                             doc2.add_row(case.diff_value, l, case.label)
                         elif self.__compare:
@@ -1097,32 +1133,33 @@ class Studies(object):
                                     doc2.addInput(ff)
 
                 # handle the input nodes that are inside postpro nodes
-                script, label, nodes, args = self.__parser.getPostPro(l)
-                doc2.appendLine("\\subsection{Results for post-processing cases}")
-                for i in range(len(label)):
-                    if script[i]:
-                        input_nodes = self.__parser.getChilds(nodes[i], "input")
-                        if input_nodes:
-                            for node in input_nodes:
-                                f, dest, repo = self.__parser.getInput(node)
-                                doc2.appendLine("\\subsubsection{%s}" % f)
+                if self.__postpro:
+                    script, label, nodes, args = self.__parser.getPostPro(l)
+                    doc2.appendLine("\\subsection{Results for post-processing cases}")
+                    for i in range(len(label)):
+                        if script[i]:
+                            input_nodes = self.__parser.getChilds(nodes[i], "input")
+                            if input_nodes:
+                                for node in input_nodes:
+                                    f, dest, repo = self.__parser.getInput(node)
+                                    doc2.appendLine("\\subsubsection{%s}" % f)
 
-                                if dest:
-                                    d = dest
-                                    dd = self.dest
-                                elif repo:
-                                    d = repo
-                                    dd = self.repo
-                                else:
-                                    d = ""
-                                    dd = ""
+                                    if dest:
+                                        d = dest
+                                        dd = self.dest
+                                    elif repo:
+                                        d = repo
+                                        dd = self.repo
+                                    else:
+                                        d = ""
+                                        dd = ""
 
-                                ff = os.path.join(dd, l, "POST", d, f)
+                                    ff = os.path.join(dd, l, "POST", d, f)
 
-                                if not os.path.isfile(ff):
-                                    print("\n\nWarning: this file does not exist: %s\n\n" % ff)
-                                else:
-                                    doc2.addInput(ff)
+                                    if not os.path.isfile(ff):
+                                        print("\n\nWarning: this file does not exist: %s\n\n" % ff)
+                                    else:
+                                        doc2.addInput(ff)
 
             attached_files.append(doc2.close())
 
