@@ -65,7 +65,12 @@ def process_cmd_line(argv, pkg):
     """
     Processes the passed command line arguments.
     """
-    parser = OptionParser(usage="usage: %prog [options]")
+    if sys.argv[0][-3:] == '.py':
+        usage = "usage: %prog [options]"
+    else:
+        usage = "usage: %prog autovnv [options]"
+
+    parser = OptionParser(usage=usage)
 
     parser.add_option("-f", "--file", dest="filename", type="string",
                       metavar="FILE", help="xml FILE of parameters")
