@@ -447,7 +447,7 @@ class case:
 
     #---------------------------------------------------------------------------
 
-    def mk_exec_dir(self, exec_basename):
+    def mk_exec_dir(self, exec_basename, force=False):
         """
         Create execution directory.
         """
@@ -456,29 +456,18 @@ class case:
 
         self.define_exec_dir(exec_basename)
 
-        # Check that directory does not exist (unless it is also
-        # the results directory, which may already have been created,
-        # but should be empty at this stage.
+        # Check that directory does not exist.
 
-        if self.result_dir != self.exec_dir:
-
-            if os.path.isdir(self.exec_dir):
+        if os.path.isdir(self.exec_dir):
+            if not force and self.result_dir != self.exec_dir:
                 err_str = \
                     '\nWorking directory: ' + self.exec_dir \
                     + ' already exists.\n' \
                     + 'Calculation will not be run.\n'
                 raise RunCaseError(err_str)
 
-            else:
-                os.makedirs(self.exec_dir)
-
-        elif (  len(os.listdir(self.exec_dir))
-              > len(self.domains) + len(self.syr_domains) + len(self.ast_domains)):
-            err_str = \
-                '\nWorking/results directory: ' + self.exec_dir \
-                + ' not empty.\n' \
-                + 'Calculation will not be run.\n'
-            raise RunCaseError(err_str)
+        else:
+            os.makedirs(self.exec_dir)
 
         # Set execution directory
 
@@ -486,7 +475,7 @@ class case:
 
     #---------------------------------------------------------------------------
 
-    def set_result_dir(self, name):
+    def set_result_dir(self, name, force=True):
 
         r = os.path.join(self.case_dir, 'RESU')
 
@@ -497,7 +486,15 @@ class case:
             if os.path.isdir(r):
                 self.result_dir = os.path.join(r, name)
 
-        if not os.path.isdir(self.result_dir):
+        if os.path.isdir(self.result_dir):
+            if not force:
+                err_str = \
+                    '\nResults directory: ' + self.result_dir \
+                    + ' already exists.\n' \
+                    + 'Calculation will not be run.\n'
+                raise RunCaseError(err_str)
+
+        else:
             os.mkdir(self.result_dir)
 
         for d in self.domains:
@@ -665,8 +662,9 @@ class case:
         cfd_d = self.domains[0]
         ast_d = self.ast_domains[0]
 
-        ast_mesh_name = ast_d.mesh
-        ast_comm = ast_d.comm
+        ast_dir_name = os.path.basename(ast_d.exec_dir)
+        ast_mesh_name = os.path.join(ast_dir_name, ast_d.mesh)
+        ast_comm = os.path.join(ast_dir_name, ast_d.comm)
 
         c = self.fsi_coupler
 
@@ -865,7 +863,9 @@ export SALOME_INSTANCE=$3
             cmd = '#mpmdbegin %d-%d\n' % (rank_id, rank_id + d.n_procs - 1)
             e.write(cmd)
             s_args = d.solver_command()
-            cmd = '#mpmdcmd ' + s_args[1] + s_args[2] + ' -wdir ' + s_args[0] + '\n'
+            cmd = '#mpmdcmd ' + os.path.relpath(s_args[1], self.exec_dir) \
+                + s_args[2] \
+                + ' -w ' + os.path.basename(s_args[0]) + '\n'
             e.write(cmd)
             e.write('#mpmdend\n')
             rank_id += d.n_procs
@@ -874,7 +874,9 @@ export SALOME_INSTANCE=$3
             cmd = '#mpmdbegin %d-%d\n' % (rank_id, rank_id + d.n_procs - 1)
             e.write(cmd)
             s_args = d.solver_command()
-            cmd = '#mpmdcmd ' + s_args[1] + s_args[2] + ' -wdir ' + s_args[0] + '\n'
+            cmd = '#mpmdcmd ' + os.path.relpath(s_args[1], self.exec_dir) \
+                + s_args[2] \
+                + ' -wdir ' + os.path.basename(s_args[0]) + '\n'
             e.write(cmd)
             e.write('#mpmdend\n')
             rank_id += d.n_procs
@@ -1259,8 +1261,9 @@ echo "exit \$?" >> $localexec
 
     def prepare_data(self,
                      n_procs = None,
-                     mpi_environment = None,
-                     run_id = None):
+                     mpiexec_options=None,
+                     run_id = None,
+                     force_id = False):
 
         """
         Prepare data for calculation.
@@ -1282,7 +1285,7 @@ echo "exit \$?" >> $localexec
 
         # Now that all domains are defined, set result copy mode
 
-        self.set_result_dir(self.run_id)
+        self.set_result_dir(self.run_id, force_id)
 
         # Create working directory (reachable by all the processors)
 
@@ -1314,10 +1317,10 @@ echo "exit \$?" >> $localexec
                                                         n_procs,
                                                         n_procs_default)
 
-        # Set user MPI environment if required.
+        # Set user MPI options if required.
 
-        if mpi_environment != None:
-            exec_env.mpi_env = mpi_environment
+        if mpiexec_options != None:
+            exec_env.mpi_env.mpiexec_options = mpiexec_options
 
         # Transfer parameters MPI parameters from user scripts here.
 
@@ -1596,9 +1599,10 @@ echo "exit \$?" >> $localexec
 
     def run(self,
             n_procs = None,
-            mpi_environment = None,
+            mpiexec_options=None,
             scratchdir = None,
             run_id = None,
+            force_id = False,
             prepare_data = True,
             run_solver = True,
             save_results = True):
@@ -1613,27 +1617,25 @@ echo "exit \$?" >> $localexec
 
             d = self.domains[0]
 
-            if hasattr(d, 'case_scratchdir'):
-                scratchdir = d.case_scratchdir
-
             if d.user_locals:
                 m = 'define_case_parameters'
                 c = globals()['case']
                 if m in d.user_locals.keys():
                     eval(m + '(case)', globals(), d.user_locals)
                     del d.user_locals[m]
-                if hasattr(c, 'scratchdir'):
-                    scratchdir = c.scratchdir
-                    del(c.scratchdir)
-                if hasattr(c, 'n_procs'):
+                if hasattr(c, 'n_procs') and n_procs == None:
                     n_procs = int(c.n_procs)
                     del(c.n_procs)
 
         # Define scratch directory
+        # priority: argument, environment variable, preference setting.
+
+        if scratchdir == None:
+            scratchdir = os.getenv('CS_SCRATCHDIR')
 
         if scratchdir == None:
 
-           # Read the possible config files
+            # Read the possible config files
 
             if sys.platform.startswith('win'):
                 username = os.getenv('USERNAME')
@@ -1641,8 +1643,7 @@ echo "exit \$?" >> $localexec
                 username = os.getenv('USER')
 
             config = configparser.ConfigParser({'user':username})
-            config.read([self.package.get_configfile(),
-                         os.path.expanduser('~/.' + self.package.configfile)])
+            config.read(self.package.get_configfiles())
 
             # Determine default execution directory if not forced;
             # If the case is already in a sub-directory of the execution
@@ -1650,13 +1651,19 @@ echo "exit \$?" >> $localexec
 
             if config.has_option('run', 'scratchdir'):
                 scratchdir = os.path.expanduser(config.get('run', 'scratchdir'))
-                scratchdir = os.path.expandvars(scratchdir)
-                if self.case_dir.find(scratchdir) == 0:
+                scratchdir = os.path.realpath(os.path.expandvars(scratchdir))
+                if os.path.realpath(self.case_dir).find(scratchdir) == 0:
                     scratchdir = None
 
         if scratchdir != None:
             self.exec_prefix = os.path.join(scratchdir, self.package.scratchdir)
 
+        # Define MPI execution options
+        # priority: argument, environment variable, preference setting, defaults.
+
+        if mpiexec_options == None:
+            mpiexec_options = os.getenv('CS_MPIEXEC_OPTIONS')
+
         if run_id != None:
             self.run_id = run_id
 
@@ -1664,7 +1671,9 @@ echo "exit \$?" >> $localexec
             retcode = 0
             if prepare_data == True:
                 retcode = self.prepare_data(n_procs,
-                                            mpi_environment)
+                                            mpiexec_options,
+                                            run_id,
+                                            force_id)
             if run_solver == True and retcode == 0:
                 self.run_solver()
 
