@@ -79,8 +79,7 @@ def get_param(path):
 
 def coupling(package,
              domains,
-             casedir,
-             pset_size):
+             casedir):
 
     use_saturne = False
     use_syrthes = False
@@ -89,7 +88,7 @@ def coupling(package,
     # Use alternate compute (back-end) package if defined
 
     config = configparser.ConfigParser()
-    config.read([package.get_configfile()])
+    config.read(package.get_global_configfile())
 
     package_compute = None
     if config.has_option('install', 'compute_versions'):
