@@ -232,7 +232,10 @@ class base_domain:
                     self.copy_result(f_src, f_dest)
 
             if purge:
-                shutil.rmtree(src)
+                if os.path.islink(src):
+                    os.remove(f)
+                else:
+                    shutil.rmtree(src)
 
     #---------------------------------------------------------------------------
 
@@ -655,11 +658,11 @@ class domain(base_domain):
 
         # User config file
         u_cfg = configparser.ConfigParser()
-        u_cfg.read(os.path.expanduser('~/.' + self.package.configfile))
+        u_cfg.read(self.package.get_user_configfile())
 
         # Global config file
         g_cfg = configparser.ConfigParser()
-        g_cfg.read(self.package.get_configfile())
+        g_cfg.read(self.package.get_global_configfile())
 
         # A mesh can be found in different mesh database directories
         # (case, study, user, global -- in this order)
@@ -1093,11 +1096,22 @@ class syrthes_domain(base_domain):
 
         # Define syrthes case structure
 
+        # Try to base Syrthes version on path used to import the syrthes module,
+        # for consistency with case creation parameters; it this is not enough,
+        # use existign environment or load one based on current configuration.
+
+        try:
+            for p in sys.path:
+                if p[-14:] == '/share/syrthes' or p[-14:] == '\share\syrthes':
+                    syr_profile = os.path.join(p[:,-14], 'bin', 'syrthes.profile')
+                    if os.path.isfile(syr_profile):
+                        source_shell_script(syr_profile)
+        except Exception:
+            pass
         try:
             if not os.getenv('SYRTHES4_HOME'):
                 config = configparser.ConfigParser()
-                config.read([self.package.get_configfile(),
-                             os.path.expanduser('~/.' + self.package.configfile)])
+                config.read(self.package.get_configfiles())
                 syr_profile = os.path.join(config.get('install', 'syrthes'),
                                            'bin', 'syrthes.profile')
                 source_shell_script(syr_profile)
@@ -1228,8 +1242,7 @@ class aster_domain(base_domain):
         # Get Code_Aster home
 
         config = configparser.ConfigParser()
-        config.read([self.package.get_configfile(),
-                     os.path.expanduser('~/.' + self.package.configfile)])
+        config.read(self.package.get_configfiles())
         self.aster_home = config.get('install', 'aster')
 
         # Additional parameters for Code_Saturne/Code_Aster coupling
@@ -1347,12 +1360,18 @@ class aster_domain(base_domain):
         from cs_exec_environment import write_shell_shebang
         write_shell_shebang(s)
 
+        aster_root = os.path.split(self.aster_home)[0]
+
         s.write('cd ..\n')
-        s.write('export PATH=' + os.path.join(self.aster_home, 'bin') + ':$PATH\n')
+        s.write('export PATH=' + os.path.join(aster_root, 'bin') + ':$PATH\n')
         s.write('as_run ' + self.param + '\n')
 
         s.close()
 
+        oldmode = (os.stat(s_path)).st_mode
+        newmode = oldmode | (stat.S_IXUSR)
+        os.chmod(s_path, newmode)
+
     #---------------------------------------------------------------------------
 
     def copy_results(self):
