@@ -45,7 +45,12 @@ def process_cmd_line(argv, pkg):
              it is split to create a list of arguments.
     """
 
-    parser = OptionParser(usage="usage: %prog [options]")
+    if sys.argv[0][-3:] == '.py':
+        usage = "usage: %prog [options]"
+    else:
+        usage = "usage: %prog compile [options]"
+
+    parser = OptionParser(usage=usage)
 
     parser.add_option("-t", "--test", dest="test_mode",
                       action="store_true",
@@ -125,14 +130,50 @@ def process_cmd_line(argv, pkg):
 
 #-------------------------------------------------------------------------------
 
-def get_compiler(pkg, compiler):
+def process_cmd_line_build(argv, pkg):
+    """
+    Processes the passed command line arguments for a build environment.
+
+    Input Argument:
+      arg -- This can be either a list of arguments as in
+             sys.argv[1:] or a string that is similar to the one
+             passed on the command line.  If it is a string,
+             it is split to create a list of arguments.
+    """
+
+    parser = OptionParser(usage="usage: %prog [options]")
+
+    parser.add_option("--mode", dest="mode", type="string",
+                      metavar="<mode>",
+                      help="'build' or 'install' mode")
+
+    parser.add_option("-d", "--dest", dest="dest_dir", type="string",
+                      metavar="<dest_dir>",
+                      help="choose executable file directory")
+
+    parser.set_defaults(build_mode=False)
+    parser.set_defaults(dest_dir=None)
+    parser.set_defaults(install_link=False)
+
+    (options, args) = parser.parse_args(argv)
+
+    if len(args) > 0:
+        parser.print_help()
+        sys.exit(1)
+
+    return options.mode, options.dest_dir
+
+#-------------------------------------------------------------------------------
+
+def get_compiler(pkg, compiler, link_build = False):
 
     # First, handle the standard "non relocatable" case
     if pkg.config.features['relocatable'] == "no":
         return pkg.config.compilers[compiler]
 
     # On Windows, compilers are installed in "bindir" for DLL search
-    if sys.platform.startswith("win"):
+    # ...unless the compilation is done during the build stage
+    if sys.platform.startswith("win") and not link_build:
         return os.path.join(pkg.get_dir('bindir'),
                             pkg.config.compilers[compiler])
 
@@ -142,7 +183,7 @@ def get_compiler(pkg, compiler):
 
 #-------------------------------------------------------------------------------
 
-def get_flags(pkg, flag):
+def get_flags(pkg, flag, link_build = False):
 
     cmd_line = []
 
@@ -164,7 +205,8 @@ def get_flags(pkg, flag):
 
     # On Windows, flags must be adapted so as to handle the relocation
     # of system headers (together with the compiler)
-    if sys.platform.startswith("win"):
+    # ...unless the compilation is done during the build stage
+    if sys.platform.startswith("win") and not link_build:
         for i in range(len(cmd_line)):
             s = cmd_line[i]
             for p in ["-I/mingw", "-Ic:/mingw"]:
@@ -177,6 +219,38 @@ def get_flags(pkg, flag):
 
 #-------------------------------------------------------------------------------
 
+def get_build_flags(pkg, flag, install=False):
+
+    cmd_line = []
+
+    # Build the command line, and split possible multiple arguments in lists.
+    for lib in pkg.config.deplibs:
+        if (pkg.config.libs[lib].have == "yes"
+            and (not pkg.config.libs[lib].dynamic_load)):
+            cmd_line += separate_args(pkg.config.libs[lib].flags[flag])
+
+    if flag == 'ldflags':
+        if not install:
+            if pkg.config.libs['ple'].variant == "internal":
+                top_builddir = os.path.split(os.path.split(os.getcwd())[0])[0]
+                ple_lib_path = os.path.join(top_builddir,
+                                            "libple", "src", ".libs")
+                cmd_line.insert(0, "-L" + ple_lib_path)
+            cmd_line.insert(0, "-L" + os.path.join(os.getcwd(), ".libs"))
+        else:
+            # Do not use pkg.get_dir here as possible relocation paths must be
+            # used after installation, not before.
+            libdir = pkg.dirs['libdir'][1]
+            # Strangely, on MinGW, Windows paths are not correctly handled here
+            # So, assuming we always build on MinGW, here is a little trick!
+            if sys.platform.startswith("win"):
+                libdir = os.path.normpath('C:\\MinGW\\msys\\1.0' + libdir)
+            cmd_line.insert(0, "-L" + libdir)
+
+    return cmd_line
+
+#-------------------------------------------------------------------------------
+
 def so_dirs_path(flags, pkg):
     """
     Assemble path for shared libraries in nonstandard directories.
@@ -301,6 +375,8 @@ def compile_and_link(pkg, srcdir, destdir,
         if (retval != 0 and not keep_going):
             break
         cmd = [get_compiler(pkg, 'fc')]
+        if f == 'cs_user_parameters.f90':
+            cmd = cmd + ["-o", "cs_f_user_parameters.o"]
         if opt_fcflags != None:
             cmd = cmd + separate_args(opt_fcflags)
         cmd = cmd + ["-I", srcdir]
@@ -345,6 +421,46 @@ def compile_and_link(pkg, srcdir, destdir,
 
     return retval
 
+#-------------------------------------------------------------------------------
+
+def link_build(pkg, install=False, destdir=None):
+    """
+    Link function for build process.
+    """
+    retval = 0
+
+    # Determine executable name
+
+    exec_name = pkg.solver
+    if destdir:
+        exec_name = os.path.join(destdir, exec_name)
+    elif install:
+        exec_name = os.path.join(pkg.dirs['pkglibexecdir'][1], exec_name)
+        # Strangely, on MinGW, Windows paths are not correctly handled here...
+        # So, assuming we always build on MinGW, here is a little trick!
+        if sys.platform.startswith("win"):
+            exec_name = os.path.normpath('C:\\MinGW\\msys\\1.0' + exec_name)
+        dirname = os.path.dirname(exec_name)
+        if not os.path.exists(dirname):
+            os.makedirs(dirname)
+
+    print("Linking executable: " + exec_name)
+
+    # Find files to compile in source path
+
+    p_libs = get_flags(pkg, 'libs', link_build = True)
+
+    cmd = [get_compiler(pkg, 'ld', link_build = True)]
+    cmd = cmd + ["-o", exec_name]
+    cmd = cmd + get_build_flags(pkg, 'ldflags', install)
+    cmd = cmd + p_libs
+    if pkg.config.rpath != "":
+        cmd += so_dirs_path(cmd, pkg)
+    if run_command(cmd, pkg=pkg, echo=True) != 0:
+        retval = 1
+
+    return retval
+
 #-------------------------------------------------------------------------------
 # Main
 #-------------------------------------------------------------------------------
@@ -373,6 +489,33 @@ def main(argv, pkg):
 
     sys.exit(retcode)
 
+#-------------------------------------------------------------------------------
+
+if __name__ == '__main__':
+
+    # Retrieve package information (name, version, installation dirs, ...)
+
+    from cs_package import package
+    pkg = package(scriptdir=os.path.realpath(__file__))
+
+    # Check if we are in a build directory
+    l = os.listdir(os.getcwd())
+    if "Makefile" in l and "libsaturne.la" in l and ".libs" in l:
+
+        from cs_exec_environment import set_modules, source_rcfile
+
+        mode, destdir = process_cmd_line_build(sys.argv[1:], pkg)
+        install = False
+        if mode == 'install':
+            install = True
+        retcode = link_build(pkg, mode, destdir)
+
+        sys.exit(retcode)
+
+    # Create an instance of the main script
+    else:
+        main(sys.argv[1:], pkg)
+
 #-------------------------------------------------------------------------------
 # End
 #-------------------------------------------------------------------------------
