@@ -60,7 +60,12 @@ def process_cmd_line(argv, pkg):
     Process the passed command line arguments.
     """
 
-    parser = OptionParser(usage="usage: %prog [options]")
+    if sys.argv[0][-3:] == '.py':
+        usage = "usage: %prog [options]"
+    else:
+        usage = "usage: %prog create [options]"
+
+    parser = OptionParser(usage=usage)
 
     parser.add_option("-s", "--study", dest="study_name", type="string",
                       metavar="<study>",
@@ -150,8 +155,7 @@ def syrthes_path_line(pkg):
     line = None
 
     config = configparser.ConfigParser()
-    config.read([pkg.get_configfile(),
-                 os.path.expanduser('~/.' + pkg.configfile)])
+    config.read(pkg.get_configfiles())
 
     if config.has_option('install', 'syrthes'):
         syr_datapath = os.path.join(config.get('install', 'syrthes'),
@@ -202,8 +206,7 @@ class Study:
         syrthes_version = None
 
         config = configparser.ConfigParser()
-        config.read([self.package.get_configfile(),
-                     os.path.expanduser('~/.' + self.package.configfile)])
+        config.read(self.package.get_configfiles())
         if config.has_option('install', 'syrthes'):
             syrthes_version = 4
 
@@ -243,8 +246,7 @@ class Study:
         # Creating Code_Aster case
         if self.ast_case_name is not None:
             config = configparser.ConfigParser()
-            config.read([self.package.get_configfile(),
-                         os.path.expanduser('~/.' + self.package.configfile)])
+            config.read(self.package.get_configfiles())
             if config.has_option('install', 'aster'):
                 self.create_aster_case(repbase)
 
@@ -264,8 +266,7 @@ class Study:
 
         try:
             config = configparser.ConfigParser()
-            config.read([self.package.get_configfile(),
-                         os.path.expanduser('~/.' + self.package.configfile)])
+            config.read(self.package.get_configfiles())
             syr_datapath = os.path.join(config.get('install', 'syrthes'),
                                         os.path.join('share', 'syrthes'))
             sys.path.insert(0, syr_datapath)
@@ -573,8 +574,7 @@ class Study:
         # Add batch system info if necessary
 
         config = configparser.ConfigParser()
-        config.read([self.package.get_configfile(),
-                     os.path.expanduser('~/.' + self.package.configfile)])
+        config.read(self.package.get_configfiles())
 
         if config.has_option('install', 'batch'):
 
