@@ -23,6 +23,12 @@
 
 #-------------------------------------------------------------------------------
 
+try:
+    import ConfigParser  # Python2
+    configparser = ConfigParser
+except Exception:
+    import configparser  # Python3
+
 import datetime
 import fnmatch
 import os
@@ -33,8 +39,6 @@ import tempfile
 
 python_version = sys.version[:3]
 
-from optparse import OptionParser
-
 #===============================================================================
 # Utility functions
 #===============================================================================
@@ -451,15 +455,8 @@ def source_rcfile(pkg):
     Source user environement if defined by rcfile in preferences file.
     """
 
-    try:
-        import ConfigParser  # Python2
-        configparser = ConfigParser
-    except Exception:
-        import configparser  # Python3
-
     config = configparser.ConfigParser()
-    config.read([pkg.get_configfile(),
-                 os.path.expanduser('~/.' + pkg.configfile)])
+    config.read(pkg.get_configfiles())
 
     if config.has_option('install', 'rcfile'):
         rcfile = config.get('install', 'rcfile')
@@ -993,9 +990,8 @@ class mpi_environment:
 
         if i > -1:
             suffix = mpiexec_path[i+1:]
-
-        if suffix in ['hydra', 'smpd', 'mpd', 'gforker', 'remshell']:
-            return suffix
+            if suffix in ['hydra', 'smpd', 'mpd', 'gforker', 'remshell']:
+                return suffix
 
         # Use mpichversion/mpich2version preferentially
 
@@ -1031,6 +1027,9 @@ class mpi_environment:
         # If MPICH2 / MPICH-3 info is not available, try
         # to determine this in another way
 
+        if os.path.islink(mpiexec_path):
+            if os.path.basename(os.path.realpath(mpiexec_path)) == 'mpiexec.py':
+                return 'mpd'
         info = get_command_outputs(mpiexec_path + ' -help')
         if info.find('Hydra') > -1:
             return 'hydra'
@@ -1116,6 +1115,8 @@ class mpi_environment:
         if (self.mpiexec == None):
             basename = 'mpiexec'
             self.mpiexec = 'mpiexec'
+        else:
+            basename = os.path.basename(self.mpiexec)
 
         # Determine if SMPD should be handled
 
@@ -1192,15 +1193,11 @@ class mpi_environment:
             if hostsfile != None:
                 self.mpiboot += ' --file=' + hostsfile
         elif pm == 'mpd':
-            if rm == 'SLURM':
-                # This requires linking with SLURM's implementation
-                # of the PMI library.
-                self.mpiexec = 'srun'
-                self.mpiexec_n = ' -n'
-                self.mpmd = MPI_MPMD_script
-                self.mpiboot = None
-                self.mpihalt = None
-            elif rm == 'PBS':
+            # For SLURM, srun can be used when linking with SLURM's
+            # implementation of the PMI library, but this is not always the
+            # case: as MPD is obsolete, users who want to use it with SLURM
+            # should define this with post-install settings (code_saturne.cfg).
+            if rm == 'PBS':
                 # Convert PBS to MPD format (based on MPICH2 documentation)
                 # before MPI boot.
                 if self.mpiboot != None:
@@ -1344,12 +1341,11 @@ class mpi_environment:
 
         if resource_info != None:
             known_manager = False
-            if resource_info.manager == 'PBS':
-                known_manager = True
-            elif os.path.isfile(info_name):
+            if os.path.isfile(info_name):
                 rc_mca_by_type = {'SLURM':' slurm ',
                                   'LSF':' lsf ',
                                   'LOADL':' loadleveler ',
+                                  'PBS':' tm ',
                                   'SGE':' gridengine '}
                 if resource_info.manager in rc_mca_by_type:
                     info = get_command_output(info_name)
@@ -1659,6 +1655,24 @@ class exec_environment:
 
         self.mpi_env = mpi_environment(pkg, self.resources, wdir)
 
+        # Modify options based on system-wide or user configuration
+
+        config = configparser.ConfigParser()
+        config.read(pkg.get_configfiles())
+
+        if config.has_section('mpi'):
+            for option in config.items('mpi'):
+               k = option[0]
+               v = option[1]
+               if not v:
+                   v = None
+               elif v[0] in ['"', "'"]:
+                   v = v[1:-1]
+               if k == 'mpmd':
+                   self.mpi_env.mpmd_mode = eval(v)
+               else:
+                   self.mpi_env.__dict__[k] = v
+
 #-------------------------------------------------------------------------------
 
 if __name__ == '__main__':
@@ -1669,8 +1683,8 @@ if __name__ == '__main__':
 
     import pprint
     pprint.pprint(e.__dict__)
-    pprint.pprint(e.resources__dict__)
-    pprint.pprint(e.mpi_env__dict__)
+    pprint.pprint(e.resources.__dict__)
+    pprint.pprint(e.mpi_env.__dict__)
     print(e.mpi_env.info())
 
 #-------------------------------------------------------------------------------
