@@ -50,7 +50,12 @@ def process_cmd_line(argv, pkg):
     Processes the passed command line arguments.
     """
 
-    parser = OptionParser(usage="usage: %prog [options]")
+    if sys.argv[0][-3:] == '.py':
+        usage = "usage: %prog [options]"
+    else:
+        usage = "usage: %prog salome [options]"
+
+    parser = OptionParser(usage=usage)
 
     (options, args) = parser.parse_args(argv)
 
@@ -104,9 +109,15 @@ export CFDSTUDY_ROOT_DIR PYTHONPATH
                 if os.path.isdir(eospath) and not eospath in sys.path:
                     path = path+":"+eospath
 
+    if pkg.name == 'neptune_cfd':
+        prefix = pkg.get_dir('csdir')
+        pythondir = pkg.get_dir('cspythondir')
+    else:
+        prefix = pkg.get_dir('prefix')
+        pythondir = pkg.get_dir('pythondir')
     cmd = template % {'salomeenv': pkg.config.salome_env,
-                      'prefix': pkg.get_dir('prefix'),
-                      'pythondir': pkg.get_dir('pythondir'),
+                      'prefix': prefix,
+                      'pythondir': pythondir,
                       'pkgpythondir': path,
                       'runsalome': run_cmd,
                       'modules': default_modules}
