@@ -181,7 +181,7 @@ if test "x$cs_gcc" = "xgcc"; then
   test -n "$cs_cc_vers_patch" || cs_cc_vers_patch=0
 
   # Default compiler flags
-  cflags_default="-std=c99 -funsigned-char -pedantic -W -Wall -Wshadow -Wpointer-arith -Wcast-qual -Wcast-align -Wwrite-strings -Wstrict-prototypes -Wmissing-prototypes -Wmissing-declarations -Wnested-externs -Wunused -Wfloat-equal"
+  cflags_default="-std=c99 -fms-extensions -funsigned-char -pedantic -W -Wall -Wshadow -Wpointer-arith -Wcast-qual -Wcast-align -Wwrite-strings -Wstrict-prototypes -Wmissing-prototypes -Wmissing-declarations -Wnested-externs -Wunused -Wfloat-equal"
   cflags_default_dbg="-g"
   cflags_default_opt="-O2"
   cflags_default_hot="-O3"
@@ -228,8 +228,9 @@ if test "x$cs_gcc" = "xgcc"; then
 
   case "$host_os" in
     mingw32)
-    cflags_default="$cflags_default -Wno-format -Wno-pedantic-ms-format"
-    ;;
+      cflags_default="`echo $cflags_default | sed -e 's/-std=c99/-std=gnu99/g'`"
+      cflags_default="$cflags_default -Wno-format -Wno-pedantic-ms-format"
+      ;;
   esac
 
 # Otherwise, are we using icc ?
@@ -393,8 +394,8 @@ if test "x$cs_cc_compiler_known" != "xyes" ; then
         cs_ibm_bg_type="Q"
         cppflags_default=""
         cflags_default=""                    # "-qlanglvl=extc99" by default
-        cflags_default_opt="-O3"
-        cflags_default_hot="-O3 -qhot"
+        cflags_default_opt="-g -O3"
+        cflags_default_hot="-g -O3 -qhot"
         cflags_default_dbg="-g"
       fi
     fi
@@ -750,8 +751,8 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
         cxxflags_default_dbg="-g"
       elif test "x$cs_ibm_bg_type" = "xQ" ; then
         cxxflags_default="-qlanglvl=redefmac"
-        cxxflags_default_opt="-O3"
-        cxxflags_default_hot="-O3 -qhot"
+        cxxflags_default_opt="-g -O3"
+        cxxflags_default_hot="-g -O3 -qhot"
         cxxflags_default_dbg="-g"
       fi
     fi
@@ -1014,7 +1015,7 @@ if test "$?" = "0" ; then
   test -n "$cs_fc_vers_patch" || cs_fc_vers_patch=0
 
   # Default compiler flags
-  fcflags_default="-x f95-cpp-input -Wall -Wno-unused"
+  fcflags_default="-x f95-cpp-input -Wall"
   fcflags_default_dbg="-g -fcheck=bounds"
   fcflags_default_opt="-O"
   fcflags_default_hot="-O2"
@@ -1130,8 +1131,8 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
       elif test "x$cs_ibm_bg_type" = "xQ" ; then
         fcflags_default="-qextname -qsuffix=cpp=f90"
         fcflags_default_dbg="-g -qcheck"
-        fcflags_default_opt="-O3"
-        fcflags_default_hot="-O3 -qhot"
+        fcflags_default_opt="-g -O3"
+        fcflags_default_hot="-g -O3 -qhot"
       fi
     fi
 
