@@ -62,7 +62,6 @@ class GuiParam(object):
     # debug
     #
     DEBUG = logging.NOTSET
-    #DEBUG = logging.DEBUG
 
 #-------------------------------------------------------------------------------
 # displaySelectedPage direct to the good page with its name
@@ -77,6 +76,7 @@ def displaySelectedPage(page_name, root, case, stbar=None, study=None, tree=None
     # 'thisPage' is the instance of classes which create thePages
     # 'page_name' is the name of the page
     #
+
     if page_name == tr("Identity and paths"):
         import Pages.IdentityAndPathesView as Page
         thisPage = Page.IdentityAndPathesView(root, case, study)
@@ -273,39 +273,41 @@ def dicoLabel(name):
     Correspondence between the names and the labels according to
     whether one is in French or in English.
     """
-    for (n, labF, labE) in [('velocity_U',           "VitesseX",  "VelocityX"),
-                            ('velocity_V',           "VitesseY",  "VelocityY"),
-                            ('velocity_W',           "VitesseZ",  "VelocityZ"),
-                            ('pressure',             "Pression",  "Pressure"),
-                            ('turb_k',               "EnerTurb",  "TurbEner"),
-                            ('turb_eps',             "Dissip",    "Dissip"),
-                            ('turb_viscosity',       "ViscTurb",  "TurbVisc"),
-                            ('component_R11',        "R11",       "R11"),
-                            ('component_R22',        "R22",       "R22"),
-                            ('component_R33',        "R33",       "R33"),
-                            ('component_R12',        "R12",       "R12"),
-                            ('component_R13',        "R13",       "R13"),
-                            ('component_R23',        "R23",       "R23"),
-                            ('turb_phi',             "phi",       "phi"),
-                            ('turb_alpha',           "alpha",     "alpha"),
-                            ('turb_omega',           "omega",     "omega"),
-                            ('turb_nusa',            "nusa",      "nusa"),
-                            ('smagorinsky_constant', "Csdyn2",    "Csdyn2"),
-                            ('temperature_celsius',  "TempC",     "TempC"),
-                            ('temperature_kelvin',   "TempK",     "TempK"),
-                            ('enthalpy',             "Enthalpie", "Enthalpy"),
-                            ('density',              "MasseVol",  "Density"),
-                            ('molecular_viscosity',  "ViscLam",   "LamVisc"),
-                            ('specific_heat',        "ChSpec",    "SpecHeat"),
-                            ('thermal_conductivity', "CondTherm", "ThermalCond"),
-                            ('dynamic_diffusion',    "DynDiff",   "DiffDyn"),
-                            ('volumic_viscosity',    "VolVisc",   "VolVisc"),
-                            ('local_time_step',      "pdtlocal",  "LocalTime"),
-                            ('courant_number',       "NbCourant", "CourantNb"),
-                            ('fourier_number',       "NbFourier", "FourierNb"),
-                            ('weight_matrix_X',      "VPsolve1",  "VPsolve1"),
-                            ('weight_matrix_Y',      "VPsolve2",  "VPsolve2"),
-                            ('weight_matrix_Z',      "VPsolve3",  "VPsolve3")]:
+    for (n, labF, labE) in [('velocity_U',                    "VitesseX",   "VelocityX"),
+                            ('velocity_V',                    "VitesseY",   "VelocityY"),
+                            ('velocity_W',                    "VitesseZ",   "VelocityZ"),
+                            ('pressure',                      "Pression",   "Pressure"),
+                            ('turb_k',                        "EnerTurb",   "TurbEner"),
+                            ('turb_eps',                      "Dissip",     "Dissip"),
+                            ('turb_viscosity',                "ViscTurb",   "TurbVisc"),
+                            ('component_R11',                 "R11",        "R11"),
+                            ('component_R22',                 "R22",        "R22"),
+                            ('component_R33',                 "R33",        "R33"),
+                            ('component_R12',                 "R12",        "R12"),
+                            ('component_R13',                 "R13",        "R13"),
+                            ('component_R23',                 "R23",        "R23"),
+                            ('turb_phi',                      "phi",        "phi"),
+                            ('turb_alpha',                    "alpha",      "alpha"),
+                            ('turb_omega',                    "omega",      "omega"),
+                            ('turb_nusa',                     "nusa",       "nusa"),
+                            ('smagorinsky_constant',          "Csdyn2",     "Csdyn2"),
+                            ('temperature_celsius',           "TempC",      "TempC"),
+                            ('temperature_kelvin',            "TempK",      "TempK"),
+                            ('enthalpy',                      "Enthalpie",  "Enthalpy"),
+                            ('potential_temperature',         "TempPot",    "PotTemp"),
+                            ('liquid_potential_temperature',  "TempPotLiq", "LiqPotTemp"),
+                            ('density',                       "MasseVol",   "Density"),
+                            ('molecular_viscosity',           "ViscLam",    "LamVisc"),
+                            ('specific_heat',                 "ChSpec",     "SpecHeat"),
+                            ('thermal_conductivity',          "CondTherm",  "ThermalCond"),
+                            ('dynamic_diffusion',             "DynDiff",    "DiffDyn"),
+                            ('volumic_viscosity',             "VolVisc",    "VolVisc"),
+                            ('local_time_step',               "pdtlocal",   "LocalTime"),
+                            ('courant_number',                "NbCourant",  "CourantNb"),
+                            ('fourier_number',                "NbFourier",  "FourierNb"),
+                            ('weight_matrix_X',               "VPsolve1",   "VPsolve1"),
+                            ('weight_matrix_Y',               "VPsolve2",   "VPsolve2"),
+                            ('weight_matrix_Z',               "VPsolve3",   "VPsolve3")]:
 
         if n == name:
             if GuiParam.lang == 'fr':
