@@ -88,10 +88,11 @@ def xmlChecker(filename):
         p = make_parser()
         p.setContentHandler(ContentHandler())
         p.parse(filename)
-    except Exception:
+    except Exception as e:
         f = os.path.basename(filename)
-        raise Exception("%s file reading error. \n\n"
-                        "This file is not in accordance with XML specifications.\n\n" % (f))
+        m = "%s file reading error. \n\n"\
+            "This file is not in accordance with XML specifications.\n\n"\
+            "The parsing syntax error is:\n\n%s" % (f, e)
 
     return m
 
@@ -129,10 +130,10 @@ class Dico:
         self.data['package']          = None
         self.data['current_page']     = ""
         self.data['current_index']    = None
-        self.data['current_tab']     = -1
+        self.data['current_tab']      = -1
         self.data['undo']             =  []
         self.data['redo']             =  []
-
+        self.data['probes']           = None
 
     def _errorExit(self, msg):
         """
